@@ -40,7 +40,6 @@ open CommonResult
 open CommonServer
 open CommonTypes
 open CommonComplexOptions
-open CommonUserDb
 
 let log_prefix = "[cInt]"
 
@@ -96,6 +95,7 @@ let hdd_full_log_closed = ref false
 let all_temp_queued = ref false
 
 let send_dirfull_warning dir full line1 =
+  if !!smtp_server <> "" && !!smtp_port <> 0 then begin
   let status = if full then "is full" else "has enough space again" in
   lprintf_nl "WARNING: Directory %s %s, %s" dir status line1;
   if (not (keep_console_output ())) then
@@ -125,15 +125,16 @@ let send_dirfull_warning dir full line1 =
           M.sendmail !!smtp_server !!smtp_port !!add_mail_brackets mail
 	with _ -> ()
     end
+  end
 
 let file_commited_name incoming_dir file =
   (try Unix2.safe_mkdir incoming_dir with _ -> ());
   let fs = Unix32.filesystem incoming_dir in
   let namemax =
     match Unix32.fnamelen incoming_dir with
-      None -> 0
-    | Some v -> Int64.to_int v in
-
+    | None -> 0
+    | Some v -> v
+  in
   let new_name =
     Filename2.filesystem_compliant 
       (canonize_basename (file_best_name file)) fs namemax in
@@ -163,6 +164,22 @@ let script_for_file file incoming new_name =
   in
   let network = network_find_by_num info.G.file_network in
   let filename = Filename.basename new_name in
+  let file_group_info =
+    match file_group file with
+    | None -> 0, []
+    | Some _ ->
+      let users = ref [] in
+      let counter = ref 0 in
+      user2_users_iter (fun u ->
+        if file_owner file <> u &&
+          user2_can_view_file u (file_owner file) (file_group file) then
+            begin
+              incr counter;
+              users :=  (Printf.sprintf "FILE_GROUP_USER_%d" !counter, u.user_name) ::
+                        (Printf.sprintf "FILE_GROUP_DIR_%d" !counter, u.user_commit_dir) :: !users
+            end);
+      !counter, !users
+  in
   begin try
   MlUnix.fork_and_exec !!file_completed_cmd
       [|  (* keep those for compatibility *)
@@ -171,7 +188,7 @@ let script_for_file file incoming new_name =
       size; (* $2 *)
       filename (* $3 *)
     |]
-     ~vars:[("TEMPNAME",  temp_name);
+     ~vars:([("TEMPNAME",  temp_name);
 	    ("FILEID",    file_id);
 	    ("FILESIZE",  size);
 	    ("FILENAME",  filename);
@@ -187,7 +204,9 @@ let script_for_file file incoming new_name =
                               (file_owner file).user_mail
                             else
                               if !!mail <> "" then !!mail else ""));
+	    ("FILE_GROUP_CNT", string_of_int (fst (file_group_info)));
 	    ]
+            @ snd (file_group_info))
 
   with e -> 
       lprintf_nl "Exception %s while executing %s"
@@ -307,7 +326,7 @@ let file_cancel file user =
 
 let mail_for_completed_file file =
   let usermail = (file_owner file).user_mail in
-  if !!mail <> "" || usermail <> "" then begin
+  if (!!mail <> "" || usermail <> "") && !!smtp_server <> "" && !!smtp_port <> 0 then begin
     let module M = Mailer in
     let info = file_info file in
     let line1 = "mldonkey has completed the download of:\r\n\r\n" in
@@ -392,7 +411,7 @@ let file_add impl state =
           | FileDownloading
           | FileQueued
           | FilePaused ->
-              files =:= file :: !!files);
+              files =:= !!files @ [file]);
         update_file_state impl state
       end
   with e ->
@@ -503,7 +522,7 @@ let display_vd = ref false
 let display_bw_stats = ref false
 
 let start_download file =
-  if !!pause_new_downloads then file_pause file admin_user;
+  if !!pause_new_downloads then file_pause file (admin_user ());
   if !!file_started_cmd <> "" then
       MlUnix.fork_and_exec  !!file_started_cmd
       [|
@@ -811,11 +830,9 @@ let all_active_network_opfile_network_names () =
        !names
 
 let apply_on_fully_qualified_options name f =
-  if !verbose then lprintf_nl "Change option %s" name;
   let rec iter prefix opfile =
     let args = simple_options prefix opfile true in
     List.iter (fun o ->
-(*        lprintf "Compare [%s] [%s]\n" o.option_name name; *)
         if o.option_name = name then
           (f opfile o.option_shortname o.option_value; raise Exit))
     args
@@ -827,7 +844,6 @@ let apply_on_fully_qualified_options name f =
             try
               List.iter (fun opfile ->
                   let prefix = r.network_shortname ^ "-" in
-(*                  lprintf "Prefix [%s]\n" prefix; *)
                   iter prefix opfile;
               )
               r.network_config_file ;
@@ -839,10 +855,6 @@ let apply_on_fully_qualified_options name f =
       end
   with Exit -> ()
 
-let set_fully_qualified_options name value =
-  apply_on_fully_qualified_options name (fun opfile old_name old_value ->
-      set_simple_option opfile old_name value)
-
 let get_fully_qualified_options name =
   let value = ref None in
   (try
@@ -851,14 +863,30 @@ let get_fully_qualified_options name =
       );
     with _ -> ());
   match !value with
-    None -> "????"
+    None -> "unknown"
   | Some s -> s
 
-let add_item_to_fully_qualified_options name value =
-  ()
-
-let del_item_from_fully_qualified_options name value =
-  ()
+let set_fully_qualified_options name value ?(user = None) ?(ip = None) ?(port = None) ?(gui_type = None) () =
+  let old_value = get_fully_qualified_options name in
+  apply_on_fully_qualified_options name
+    (fun opfile old_name old_value -> set_simple_option opfile old_name value);
+  if !verbose && old_value <> get_fully_qualified_options name then
+    begin
+      let ip_port_text =
+        match ip with
+        | None -> "IP unknown"
+        | Some ip ->
+            Printf.sprintf "from host %s%s" (Ip.to_string ip)
+              (match port with | None -> "" | Some port -> Printf.sprintf ":%d" port)
+      in
+      lprintf_nl "User %s changed option %s %s %s, old: %s, new %s"
+        (match user with | None -> "unknown" | Some user -> user)
+        name ip_port_text
+        (match gui_type with
+        | None -> "GUI type unknown"
+        | Some gt -> Printf.sprintf "using %s interface" (connection_type_to_text gt))
+        old_value (get_fully_qualified_options name)
+    end
 
 let keywords_of_query query =
   let keywords = ref [] in
@@ -953,7 +981,7 @@ let force_download_quotas () =
   let queue_files files =
     List.iter (fun file ->
       if file_state file = FileDownloading then
-	set_file_state file FileQueued
+	file_queue file
     ) files in
 
   let queue_user_file_list (_user, user_file_list) =
@@ -1038,7 +1066,7 @@ let force_download_quotas () =
 	      match file_state first_file with
 	      | FileDownloading -> true
 	      | FileQueued ->
-		  set_file_state first_file FileDownloading;
+		  file_resume first_file (admin_user ());
 		  true
 	      | _ -> false in
 	    if is_downloading then
