@@ -1282,9 +1282,9 @@ let temp_directory = define_option current_section ["temp_directory"]
 let share_scan_interval = define_option current_section ["share_scan_interval"]
   ~restart: true
   "How often (in minutes) should MLDonkey scan all shared directories for new/removed files.
-  0 to disable scanning of shared directories. Use command reshare to manually scan shares.
-  When core starts all shared directories are scanned once, independent of this option."
-    int_option 1
+  Minimum 5, 0 to disable. Use command reshare to manually scan shares.
+  When core starts, shared directories are scanned once, independent of this option."
+    int_option 30
 
 let create_file_mode = define_option current_section ["create_file_mode"]
   "New download files are created with these rights (in octal)"
@@ -1363,7 +1363,7 @@ let allow_browse_share = define_option current_section ["allow_browse_share"]
 
 let messages_filter = define_option current_section ["messages_filter"]
   "Regexp of messages to filter out, example: string1|string2|string3"
-    string_option "DI-Emule|ZamBoR|Ketamine|eMule FX|AUTOMATED MESSAGE"
+    string_option "DI-Emule|ZamBoR|Ketamine|eMule FX|AUTOMATED MESSAGE|Hi Honey!|Do you live in my area|download HyperMule"
 
 let comments_filter = define_option current_section ["comments_filter"]
   "Regexp of comments to filter out, example: string1|string2|string3"
@@ -1598,7 +1598,7 @@ let max_displayed_results = define_expert_option current_section ["max_displayed
 let options_version = define_expert_option current_section ["options_version"]
   ~internal: true
   "(internal option)"
-    int_option 18
+    int_option 20
 
 let max_comments_per_file = define_expert_option current_section ["max_comments_per_file"]
   "Maximum number of comments per file"
@@ -1666,7 +1666,7 @@ let client_ip sock =
   else
     if !last_high_id <> Ip.null then
       begin
-        if !last_high_id <> Ip.localhost && !!set_client_ip <> !last_high_id then
+        if Ip.usable !last_high_id && !!set_client_ip <> !last_high_id then
           set_client_ip =:= !last_high_id;
         !last_high_id
       end
@@ -1675,8 +1675,8 @@ let client_ip sock =
         None -> !!set_client_ip
       | Some sock ->
           let ip = TcpBufferedSocket.my_ip sock in
-          if ip <> Ip.localhost && !!set_client_ip <> ip then
-          set_client_ip =:= ip;
+          if Ip.usable ip && !!set_client_ip <> ip then
+            set_client_ip =:= ip;
           ip
 
 let start_running_plugins = ref false
@@ -1732,7 +1732,7 @@ let _ =
     if !!min_reask_delay < 600 then min_reask_delay =:= 600
   );
   option_hook share_scan_interval (fun _ ->
-    if !!share_scan_interval < 0 then share_scan_interval =:= 1
+    if !!share_scan_interval < 5 && !!share_scan_interval <> 0 then share_scan_interval =:= 5
   );
   option_hook global_login (fun _ ->
       let len = String.length !!global_login in
@@ -2170,4 +2170,13 @@ let rec update_options () =
       web_infos_add "hublist" 0 "http://dchublist.com/hublist.config.bz2";
       update 18
 
+  | 18 ->
+      if !!messages_filter = "DI-Emule|ZamBoR|Ketamine|eMule FX|AUTOMATED MESSAGE" then
+        messages_filter =:= "DI-Emule|ZamBoR|Ketamine|eMule FX|AUTOMATED MESSAGE|Hi Honey!|Do you live in my area|download HyperMule";
+      update 19
+
+  | 19 ->
+      if !!share_scan_interval = 5 then share_scan_interval =:= 30;
+      update 20
+
   | _ -> ()
