@@ -87,7 +87,6 @@ let second_timer timer =
      CommonUploads.refill_upload_slots ()
    with e ->
         lprintf_nl (_b "Exception %s") (Printexc2.to_string e));
-  CommonUploads.reset_upload_timer ();
   CommonUploads.shared_files_timer ();
   ()
 
@@ -424,6 +423,20 @@ or getting a binary compiled with glibc %s.\n\n")
 
   CommonGlobals.is_startup_phase := false;
 
+(* before activating network modules load all local files from web_infos/
+   to avoid security holes, especially for IP blocking *)
+  Hashtbl.iter (fun key w ->
+    let file = Filename.concat "web_infos" (Filename.basename w.url) in
+    if Sys.file_exists file then
+      try
+        lprintf_nl "loading %s from %s" w.kind file;
+        ((List.assoc w.kind !CommonWeb.file_kinds).f w.url) file;
+        w.state <- Some FileLoaded;
+      with _ -> ()
+  ) web_infos_table;
+
+  discover_ip false;
+
   lprintf_nl (_b "Check http://www.mldonkey.org for updates");
   networks_iter (fun r -> network_load_complex_options r);
   lprintf_nl (_b "enabling networks: ");
@@ -465,6 +478,7 @@ or getting a binary compiled with glibc %s.\n\n")
   add_infinite_timer 0.1 CommonUploads.upload_download_timer;
   add_infinite_timer !!buffer_writes_delay (fun _ -> Unix32.flush ());
 
+  if !!share_scan_interval <> 0 then
   add_infinite_timer ((float_of_int !!share_scan_interval) *. 60.)
     (fun _ -> CommonShared.shared_check_files ());
   CommonShared.shared_check_files ();
@@ -501,7 +515,6 @@ or getting a binary compiled with glibc %s.\n\n")
 
   Options.prune_file downloads_ini;
   Options.prune_file users_ini;
-(*  Options.prune_file downloads_expert_ini; *)
   add_timer 1. (fun _ -> try CommonWeb.load_web_infos true false with _ -> ());
   lprintf_nl  (_b "To command: telnet %s %d")
 	(if !!telnet_bind_addr = Ip.any then "127.0.0.1"
@@ -564,11 +577,12 @@ or getting a binary compiled with glibc %s.\n\n")
 
   if not Autoconf.windows then
     MlUnix.set_signal  Sys.sighup
-      (Sys.Signal_handle (fun _ -> lprintf_nl (_b "Received SIGHUP, closing all files and client/server sockets");
+      (Sys.Signal_handle (fun _ -> lprintf_nl (_b "Received SIGHUP, closing all files and client/server sockets, start IP discovery");
          networks_iter (fun r -> CommonNetwork.network_reset r); (* stop_all_bt *)
 	 CommonServer.disconnect_all_servers ();
 	 CommonClient.disconnect_all_clients ();
-	 Unix32.close_all () (* close all files *)
+         Unix32.close_all (); (* close all files *)
+         discover_ip false;
          ));
 
   if not Autoconf.windows then
