@@ -252,6 +252,11 @@ let op_file_print file o =
         "" -> "-"
       | _ -> file.file_encoding) ];
 
+  Printf.bprintf buf "\\</tr\\>\\<tr class=\\\"dl-%d\\\"\\>" (html_mods_cntr ());
+  html_mods_td buf [
+    ("Piece size", "sr br", "Piece size");
+    ("", "sr", Int64.to_string file.file_piece_size) ];
+
   let rec print_first_tracker l =
     match l with
       | [] -> ()
@@ -579,6 +584,9 @@ let op_file_info file =
     P.file_chunks = (match file.file_swarmer with
     | None -> None 
     | Some swarmer -> Some (CommonSwarming.chunks_verified_bitmap swarmer));
+    P.file_chunk_size = (match file.file_swarmer with
+    | None -> None 
+    | Some t -> Some (List.map (fun t -> t.CommonSwarming.t_chunk_size) t.CommonSwarming.t_s.CommonSwarming.s_networks));
     P.file_availability =
     [network.network_num,(match file.file_swarmer with
           None -> "" | Some swarmer ->
@@ -613,6 +621,7 @@ let op_ft_info ft =
     P.file_sources = None;
     P.file_download_rate = 0.;
     P.file_chunks = None;
+    P.file_chunk_size = None;
     P.file_availability =  [network.network_num, ""];
     P.file_format = FormatNotComputed 0;
     P.file_chunks_age = [| last_time () |];
@@ -630,7 +639,7 @@ let op_ft_info ft =
 
 
 
-let load_torrent_string s user =
+let load_torrent_string s user group =
   if !verbose then lprintf_nl "load_torrent_string";
   let file_id, torrent = BTTorrent.decode_torrent s in
 
@@ -663,12 +672,12 @@ let load_torrent_string s user =
   if !verbose then
     lprintf_nl "Starting torrent download with diskname: %s"
         torrent_diskname;
-  let file = new_download file_id torrent torrent_diskname user in
+  let file = new_download file_id torrent torrent_diskname user group in
   BTClients.get_sources_from_tracker file;
   CommonInteractive.start_download (file_find (file_num file));
   file
 
-let load_torrent_file filename user =
+let load_torrent_file filename user group =
   if !verbose then
     lprintf_nl "load_torrent_file %s" filename;
   let s = File.to_string filename in
@@ -677,7 +686,7 @@ let load_torrent_file filename user =
   if Sys.file_exists filename
       && (Filename.dirname filename) = downloads_directory then
     Sys.remove filename;
-  ignore (load_torrent_string s user)
+  ignore (load_torrent_string s user group)
 
 let parse_tracker_reply file t filename =
 (*This is the function which will be called by the http client
@@ -742,8 +751,9 @@ let try_share_file torrent_diskname =
       iter (shared_directories_including_user_commit ())
     in
 
+    let user = CommonUserDb.admin_user () in
     let file = new_file file_id torrent torrent_diskname
-        filename FileShared (CommonUserDb.admin_user ()) in
+        filename FileShared user user.user_default_group in
     if !verbose_share then lprintf_file_nl (as_file file) "Sharing file %s" filename;
     BTClients.connect_trackers file "started"
       (parse_tracker_reply file)
@@ -793,8 +803,13 @@ let scan_new_torrents_directory () =
     let file_basename = Filename.basename file in
     if not (Unix2.is_directory file) then
     try
-      let user = fst (Unix32.owner file) in
-      load_torrent_file file (try CommonUserDb.user2_user_find user with Not_found -> CommonUserDb.admin_user ());
+      let file_owner = fst (Unix32.owner file) in
+      let user =
+        try
+          CommonUserDb.user2_user_find file_owner
+        with Not_found -> CommonUserDb.admin_user ()
+      in
+      load_torrent_file file user user.user_default_group;
       (try Sys.remove file with _ -> ())
     with 
       Torrent_can_not_be_used _ ->
@@ -812,11 +827,11 @@ let retry_all_ft () =
           lprintf_nl "ft_retry: exception %s" (Printexc2.to_string e)
   ) ft_by_num
 
-let load_torrent_from_web r user ft =
+let load_torrent_from_web r user group ft =
   let module H = Http_client in
   H.wget r (fun filename ->
       if ft_state ft = FileDownloading then begin
-          load_torrent_file filename user;
+          load_torrent_file filename user group;
           file_cancel (as_ft ft) (CommonUserDb.admin_user ())
         end)
 
@@ -830,7 +845,7 @@ let get_regexp_string text r =
   let b = Str.group_end 1 in
   String.sub text a (b - a)
 
-let op_network_parse_url url user =
+let op_network_parse_url url user group =
   let location_regexp = "Location: \\(.*\\)" in
   try
     let real_url = get_regexp_string url (Str.regexp location_regexp) in
@@ -866,8 +881,8 @@ let op_network_parse_url url user =
 
         let file_diskname = Filename.basename u.Url.short_file in
         let ft = new_ft file_diskname user in
-        ft.ft_retry <- (load_torrent_from_web r user);
-        load_torrent_from_web r user ft;
+        ft.ft_retry <- (load_torrent_from_web r user group);
+        load_torrent_from_web r user group ft;
         "started download", true
       )
     else
@@ -878,7 +893,7 @@ let op_network_parse_url url user =
         try
           if !verbose then lprintf_nl "Not_found and trying to load %s" url;
           try
-            load_torrent_file url user;
+            load_torrent_file url user group;
             "", true
           with
 	    Torrent_already_exists _ -> "A torrent with this name is already in the download queue", false
@@ -1121,13 +1136,13 @@ let commands =
       let buf = o.conn_buf in
       if Sys.file_exists url then
         begin
-	  load_torrent_file url o.conn_user.ui_user;
+	  load_torrent_file url o.conn_user.ui_user o.conn_user.ui_user.user_default_group;
           Printf.bprintf buf "loaded file %s\n" url
 	end
       else
         begin
           let url = "Location: " ^ url ^ "\nContent-Type: application/x-bittorrent" in
-	  let result = fst (op_network_parse_url url o.conn_user.ui_user) in
+	  let result = fst (op_network_parse_url url o.conn_user.ui_user o.conn_user.ui_user.user_default_group) in
           Printf.bprintf buf "%s\n" result
 	end;
       _s ""
@@ -1208,7 +1223,7 @@ let op_gui_message s user =
       let text = String.sub s 2 (String.length s - 2) in
       if !verbose then lprintf_nl "received torrent from gui...";
       (try
-        let file = load_torrent_string text user in
+        let file = load_torrent_string text user user.user_default_group in
         raise (Torrent_started file.file_name)
       with e -> (match e with
 	| Torrent_can_not_be_used s -> lprintf_nl "Loading torrent from GUI: torrent %s can not be used" s
@@ -1265,7 +1280,7 @@ let _ =
   network.op_network_forget_search <- (fun s -> ());
   network.op_network_connect_servers <- (fun s -> ());
   network.op_network_search <- (fun ss buf -> ());
-  network.op_network_download <- (fun r user -> dummy_file);
+  network.op_network_download <- (fun r user group -> dummy_file);
   network.op_network_recover_temp <- (fun s -> ());
   let clean_exit_started = ref false in
   network.op_network_clean_exit <- (fun s ->
