@@ -954,7 +954,7 @@ static int statfs (const unsigned char *path, struct statfs *buf)
     FARPROC f;
     int retval = 0;
     WCHAR tmp [MAX_PATH], resolved_path [MAX_PATH];
-    WCHAR * wpath=utf8_to_utf16(path);
+    WCHAR * wpath = (WCHAR *)utf8_to_utf16(path);
     realpath(wpath, resolved_path);
     free(wpath);
     if (!resolved_path)
@@ -1101,16 +1101,11 @@ copy_statfs (struct statfs *buf)
   v = copy_int64 (buf->f_frsize); caml_modify (&Field (bufv, 10), v);
 #else
 #if defined(__FreeBSD__) || defined(__OpenBSD__) || defined(__NetBSD__) || defined(__APPLE__) || defined(__DragonFly__)
-#  if defined(__OpenBSD__) || defined(__NetBSD__) || (defined(__FreeBSD__) && __FreeBSD_version < 502000) || defined(__DragonFly__)
+#  if defined(__OpenBSD__) || defined(__NetBSD__) || (defined(__FreeBSD__) && __FreeBSD_version < 502000) || defined(__DragonFly__) || defined(__APPLE__)
 #    include <sys/syslimits.h>
      v = copy_int64 (NAME_MAX); caml_modify (&Field (bufv, 8), v);
 #  else
-#    if defined(__APPLE__)
-#      include <unistd.h>
-       v = copy_int64 (_PC_NAME_MAX); caml_modify (&Field (bufv ,8 ), v);
-#    else
-       v = copy_int64 (buf->f_namemax); caml_modify (&Field (bufv, 8), v);
-#    endif /* (__APPLE__) */
+     v = copy_int64 (buf->f_namemax); caml_modify (&Field (bufv, 8), v);
 #  endif /* (__OpenBSD__) || defined(__NetBSD__) || (defined(__FreeBSD__) && __FreeBSD_version < 502000) */
   v = copy_string (buf->f_fstypename); caml_modify (&Field (bufv, 9), v);
 #else
